@@ -45,26 +45,26 @@ KPlayerPlaylist::KPlayerPlaylist (TDEActionCollection* ac, TQObject* parent, con
   m_ac = ac;
   m_current = 0;
   m_play_requested = false;
-  TDEAction* action = KStdAction::open (this, SLOT (filePlay()), m_ac);
+  TDEAction* action = KStdAction::open (this, TQ_SLOT (filePlay()), m_ac);
   action -> setText (i18n("&Play..."));
   action -> setStatusText (i18n("Plays an existing file"));
   action -> setWhatsThis (i18n("Play command displays the standard Open File dialog and lets you choose a file or several files to put on the playlist and start playing."));
-  action = new TDEAction (i18n("Play &URL..."), "fileopenurl", CTRL + Key_U, this, SLOT (filePlayUrl()), m_ac, "file_open_url");
+  action = new TDEAction (i18n("Play &URL..."), "fileopenurl", CTRL + Key_U, this, TQ_SLOT (filePlayUrl()), m_ac, "file_open_url");
   action -> setStatusText (i18n("Plays a URL"));
   action -> setWhatsThis (i18n("Play URL command displays the standard URL dialog and lets you type or paste in a URL to put on the playlist and start playing. The URL can be a remote network location, a local file path, or a TDE I/O Slave URL."));
   m_playlists = new KPlayerContainerActionList ("%1", i18n("Plays the %1 list"),
     i18n("Play List %1 starts playing the list."), this, "play_list");
-  connect (playlistActionList(), SIGNAL (activated (KPlayerNode*)), SLOT (play (KPlayerNode*)));
+  connect (playlistActionList(), TQ_SIGNAL (activated (KPlayerNode*)), TQ_SLOT (play (KPlayerNode*)));
   m_recent = new KPlayerNodeActionList ("%1", i18n("Plays %1"),
     i18n("Play Recent %1 starts playing the recently played item."), this, "file_recent");
-  connect (recentActionList(), SIGNAL (activated (KPlayerNode*)), SLOT (play (KPlayerNode*)));
+  connect (recentActionList(), TQ_SIGNAL (activated (KPlayerNode*)), TQ_SLOT (play (KPlayerNode*)));
   refreshSettings();
   m_devices = new KPlayerDevicesActionList ("%1", i18n("Shows commands and options available for %1"),
     i18n("Submenu that shows commands and options available for %1."), this, "file_devices");
-  action = new TDEAction (i18n("&Next"), "1rightarrow", ALT + Key_Down, this, SLOT (next()), m_ac, "player_next");
+  action = new TDEAction (i18n("&Next"), "1rightarrow", ALT + Key_Down, this, TQ_SLOT (next()), m_ac, "player_next");
   action -> setStatusText (i18n("Plays the next item on the playlist"));
   action -> setWhatsThis (i18n("Next command starts playing the next item on the current playlist."));
-  action = new TDEAction (i18n("P&revious"), "1leftarrow", ALT + Key_Up, this, SLOT (previous()), m_ac, "player_previous");
+  action = new TDEAction (i18n("P&revious"), "1leftarrow", ALT + Key_Up, this, TQ_SLOT (previous()), m_ac, "player_previous");
   action -> setStatusText (i18n("Plays the previous item on the playlist"));
   action -> setWhatsThis (i18n("Previous command starts playing the previous item on the current playlist."));
   KWidgetAction* widget = new KWidgetAction (new KPlayerPlaylistCombobox, i18n("Playlist"), 0, 0, 0, m_ac, "player_list");
@@ -72,36 +72,36 @@ KPlayerPlaylist::KPlayerPlaylist (TDEActionCollection* ac, TQObject* parent, con
   widget -> setShortcutConfigurable (false);
   widget -> setStatusText (i18n("Shows playlist items and allows you to select an item to play"));
   widget -> setWhatsThis (i18n("Playlist combo box in the closed state displays the current playlist item. You can drop down the combo box to see the entire list and select a different item to load and play."));
-  connect (playlist(), SIGNAL (activated(int)), SLOT (play(int)));
+  connect (playlist(), TQ_SIGNAL (activated(int)), TQ_SLOT (play(int)));
   TQToolTip::add (playlist(), i18n("Playlist"));
-  TDEToggleAction* toggle = new TDEToggleAction (i18n("&Loop"), "loop", 0, this, SLOT (loop()), m_ac, "player_loop");
+  TDEToggleAction* toggle = new TDEToggleAction (i18n("&Loop"), "loop", 0, this, TQ_SLOT (loop()), m_ac, "player_loop");
   toggle -> setStatusText (i18n("Turns the option to loop through the list on/off"));
   toggle -> setWhatsThis (i18n("Loop command toggles the option to start playing items from the beginning of the playlist after playing the last item on the playlist."));
   if ( configuration() -> loop() )
     toggle -> setChecked (true);
-  toggle = new TDEToggleAction (i18n("S&huffle"), "shuffle", 0, this, SLOT (shuffle()), m_ac, "player_shuffle");
+  toggle = new TDEToggleAction (i18n("S&huffle"), "shuffle", 0, this, TQ_SLOT (shuffle()), m_ac, "player_shuffle");
   toggle -> setStatusText (i18n("Turns the option to play items in random order on or off"));
   toggle -> setWhatsThis (i18n("Shuffle command toggles the option to play items in a random order."));
   if ( configuration() -> shuffle() )
     toggle -> setChecked (true);
-  action = new TDEAction (i18n("&Files..."), 0, 0, this, SLOT (addFiles()), m_ac, "playlist_add_files");
+  action = new TDEAction (i18n("&Files..."), 0, 0, this, TQ_SLOT (addFiles()), m_ac, "playlist_add_files");
   action -> setStatusText (i18n("Adds files to the playlist"));
   action -> setWhatsThis (i18n("Add files command displays the standard Open File dialog and lets you choose a file or several files to add to the playlist."));
-  action = new TDEAction (i18n("&URL..."), 0, 0, this, SLOT (addUrl()), m_ac, "playlist_add_url");
+  action = new TDEAction (i18n("&URL..."), 0, 0, this, TQ_SLOT (addUrl()), m_ac, "playlist_add_url");
   action -> setStatusText (i18n("Adds a URL to the playlist"));
   action -> setWhatsThis (i18n("Add URL command displays the standard Open URL dialog and lets you type or paste in a URL to add to the playlist."));
-  action = new TDEAction (i18n("&Playlists..."), 0, 0, this, SLOT (addToPlaylists()), m_ac, "playlist_add_to_playlists");
+  action = new TDEAction (i18n("&Playlists..."), 0, 0, this, TQ_SLOT (addToPlaylists()), m_ac, "playlist_add_to_playlists");
   action -> setStatusText (i18n("Saves the playlist under a new name"));
   action -> setWhatsThis (i18n("Add to new playlist command prompts for a new playlist name and saves the playlist under the new name."));
   m_playlists_add = new KPlayerContainerActionList ("%1", i18n("Adds playlist items to %1 playlist"),
     i18n("Add to playlist command adds the playlist items to the %1 playlist."), this, "playlist_add_to_playlist");
   playlistAddActionList() -> setMaximumSize (configuration() -> playlistMenuSize());
-  action = new TDEAction (i18n("&Collection..."), 0, 0, this, SLOT (addToCollection()), m_ac, "playlist_add_to_collection");
+  action = new TDEAction (i18n("&Collection..."), 0, 0, this, TQ_SLOT (addToCollection()), m_ac, "playlist_add_to_collection");
   action -> setStatusText (i18n("Saves the playlist in the collection"));
   action -> setWhatsThis (i18n("Add to collection command prompts for a new folder name and saves the playlist under the new name in the multimedia collection."));
-  connect (process(), SIGNAL (stateChanged(KPlayerProcess::State, KPlayerProcess::State)),
-    SLOT (playerStateChanged(KPlayerProcess::State, KPlayerProcess::State)));
-  connect (configuration(), SIGNAL (updated()), this, SLOT (refreshSettings()));
+  connect (process(), TQ_SIGNAL (stateChanged(KPlayerProcess::State, KPlayerProcess::State)),
+    TQ_SLOT (playerStateChanged(KPlayerProcess::State, KPlayerProcess::State)));
+  connect (configuration(), TQ_SIGNAL (updated()), this, TQ_SLOT (refreshSettings()));
   m_nowplaying = (KPlayerNowPlayingNode*) KPlayerNode::root() -> getNodeByUrl ("kplayer:/nowplaying");
   nowplaying() -> reference();
 }
@@ -166,12 +166,12 @@ void KPlayerPlaylist::attach (KPlayerContainerNode* node)
   kdDebugTime() << "KPlayerPlaylist::attach\n";
 #endif
   node -> populate();
-  connect (node, SIGNAL (nodesAdded (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)),
-    SLOT (added (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)));
-  connect (node, SIGNAL (nodesRemoved (KPlayerContainerNode*, const KPlayerNodeList&)),
-    SLOT (removed (KPlayerContainerNode*, const KPlayerNodeList&)));
-  connect (node, SIGNAL (nodeUpdated (KPlayerContainerNode*, KPlayerNode*)),
-    SLOT (updated (KPlayerContainerNode*, KPlayerNode*)));
+  connect (node, TQ_SIGNAL (nodesAdded (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)),
+    TQ_SLOT (added (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)));
+  connect (node, TQ_SIGNAL (nodesRemoved (KPlayerContainerNode*, const KPlayerNodeList&)),
+    TQ_SLOT (removed (KPlayerContainerNode*, const KPlayerNodeList&)));
+  connect (node, TQ_SIGNAL (nodeUpdated (KPlayerContainerNode*, KPlayerNode*)),
+    TQ_SLOT (updated (KPlayerContainerNode*, KPlayerNode*)));
 }
 
 void KPlayerPlaylist::detach (KPlayerContainerNode* node)
