@@ -89,8 +89,8 @@ KPlayerLineOutputProcess::KPlayerLineOutputProcess (void)
 #if 0
   m_merge = false;
 #endif
-  connect (this, SIGNAL (receivedStdout (TDEProcess*, char*, int)), SLOT (slotReceivedStdout (TDEProcess*, char*, int)));
-  connect (this, SIGNAL (receivedStderr (TDEProcess*, char*, int)), SLOT (slotReceivedStderr (TDEProcess*, char*, int)));
+  connect (this, TQ_SIGNAL (receivedStdout (TDEProcess*, char*, int)), TQ_SLOT (slotReceivedStdout (TDEProcess*, char*, int)));
+  connect (this, TQ_SIGNAL (receivedStderr (TDEProcess*, char*, int)), TQ_SLOT (slotReceivedStderr (TDEProcess*, char*, int)));
 }
 
 KPlayerLineOutputProcess::~KPlayerLineOutputProcess()
@@ -337,10 +337,10 @@ void KPlayerProcess::transferTemporaryFile (void)
     m_temp_job = TDEIO::get (properties() -> url(), false, false);
     m_temp_job -> setWindow (kPlayerWorkspace());
     m_temp_job -> addMetaData ("PropagateHttpHeader", "true");
-    connect (m_temp_job, SIGNAL (data (TDEIO::Job*, const TQByteArray&)), SLOT (transferTempData (TDEIO::Job*, const TQByteArray&)));
-    connect (m_temp_job, SIGNAL (result (TDEIO::Job*)), SLOT (transferTempDone (TDEIO::Job*)));
-    connect (m_temp_job, SIGNAL (percent (TDEIO::Job*, unsigned long)), SLOT (transferProgress (TDEIO::Job*, unsigned long)));
-    connect (m_temp_job, SIGNAL (infoMessage (TDEIO::Job*, const TQString&)), SLOT (transferInfoMessage (TDEIO::Job*, const TQString&)));
+    connect (m_temp_job, TQ_SIGNAL (data (TDEIO::Job*, const TQByteArray&)), TQ_SLOT (transferTempData (TDEIO::Job*, const TQByteArray&)));
+    connect (m_temp_job, TQ_SIGNAL (result (TDEIO::Job*)), TQ_SLOT (transferTempDone (TDEIO::Job*)));
+    connect (m_temp_job, TQ_SIGNAL (percent (TDEIO::Job*, unsigned long)), TQ_SLOT (transferProgress (TDEIO::Job*, unsigned long)));
+    connect (m_temp_job, TQ_SIGNAL (infoMessage (TDEIO::Job*, const TQString&)), TQ_SLOT (transferInfoMessage (TDEIO::Job*, const TQString&)));
     transferProgress (m_temp_job, 0);
     m_delayed_helper = true;
   }
@@ -438,8 +438,8 @@ void KPlayerProcess::get_info (void)
     *m_helper << "-nocache";
   else if ( properties() -> cache() == 2 )
     *m_helper << "-cache" << TQString::number (properties() -> cacheSize());
-  connect (m_helper, SIGNAL (receivedStdoutLine (KPlayerLineOutputProcess*, char*, int)),
-    SLOT (receivedHelperLine (KPlayerLineOutputProcess*, char*, int)));
+  connect (m_helper, TQ_SIGNAL (receivedStdoutLine (KPlayerLineOutputProcess*, char*, int)),
+    TQ_SLOT (receivedHelperLine (KPlayerLineOutputProcess*, char*, int)));
   if ( ! run (m_helper) )
   {
     delete m_helper;
@@ -680,10 +680,10 @@ void KPlayerProcess::start (void)
   }
   else
     m_fifo_name = TQCString();
-  connect (m_player, SIGNAL (receivedStdoutLine (KPlayerLineOutputProcess*, char*, int)),
-    SLOT (receivedOutputLine (KPlayerLineOutputProcess*, char*, int)));
-  connect (m_player, SIGNAL (receivedStderrLine (KPlayerLineOutputProcess*, char*, int)),
-    SLOT (receivedOutputLine (KPlayerLineOutputProcess*, char*, int)));
+  connect (m_player, TQ_SIGNAL (receivedStdoutLine (KPlayerLineOutputProcess*, char*, int)),
+    TQ_SLOT (receivedOutputLine (KPlayerLineOutputProcess*, char*, int)));
+  connect (m_player, TQ_SIGNAL (receivedStderrLine (KPlayerLineOutputProcess*, char*, int)),
+    TQ_SLOT (receivedOutputLine (KPlayerLineOutputProcess*, char*, int)));
   if ( ! run (m_player) )
   {
     delete m_player;
@@ -704,9 +704,9 @@ void KPlayerProcess::start (void)
     m_slave_job = TDEIO::get (properties() -> url(), false, false);
     m_slave_job -> setWindow (kPlayerWorkspace());
     m_slave_job -> addMetaData ("PropagateHttpHeader", "true");
-    connect (m_slave_job, SIGNAL (data (TDEIO::Job*, const TQByteArray&)), SLOT (transferData (TDEIO::Job*, const TQByteArray&)));
-    connect (m_slave_job, SIGNAL (result (TDEIO::Job*)), SLOT (transferDone (TDEIO::Job*)));
-    connect (m_slave_job, SIGNAL (infoMessage (TDEIO::Job*, const TQString&)), SLOT (transferInfoMessage (TDEIO::Job*, const TQString&)));
+    connect (m_slave_job, TQ_SIGNAL (data (TDEIO::Job*, const TQByteArray&)), TQ_SLOT (transferData (TDEIO::Job*, const TQByteArray&)));
+    connect (m_slave_job, TQ_SIGNAL (result (TDEIO::Job*)), TQ_SLOT (transferDone (TDEIO::Job*)));
+    connect (m_slave_job, TQ_SIGNAL (infoMessage (TDEIO::Job*, const TQString&)), TQ_SLOT (transferInfoMessage (TDEIO::Job*, const TQString&)));
     m_cache_size = properties() -> cache() == 2 ? properties() -> cacheSize() * 1024 : 1048576;
     m_first_chunk = true;
 #ifdef DEBUG_KPLAYER_PROCESS
@@ -769,7 +769,7 @@ bool KPlayerProcess::run (KPlayerLineOutputProcess* player)
     *player << (properties() -> useTemporaryFile() && m_temporary_file ? TQFile::encodeName (m_temporary_file -> name()) : m_fifo_name);
   else
     *player << properties() -> urlString();
-  connect (player, SIGNAL (processExited (TDEProcess*)), SLOT (playerProcessExited (TDEProcess*)));
+  connect (player, TQ_SIGNAL (processExited (TDEProcess*)), TQ_SLOT (playerProcessExited (TDEProcess*)));
 #if 0
   player -> setMerge (true);
 #endif
@@ -1523,7 +1523,7 @@ void KPlayerProcess::sendFifoData (void)
       }
       m_fifo_notifier = new TQSocketNotifier (m_fifo_handle, TQSocketNotifier::Write);
       m_fifo_notifier -> setEnabled (false);
-      connect (m_fifo_notifier, SIGNAL (activated (int)), SLOT (playerDataWritten (int)));
+      connect (m_fifo_notifier, TQ_SIGNAL (activated (int)), TQ_SLOT (playerDataWritten (int)));
     }
     else if ( ! m_fifo_timer )
     {
@@ -1531,7 +1531,7 @@ void KPlayerProcess::sendFifoData (void)
       kdDebugTime() << "Process: fifo open failed, creating timer\n";
 #endif
       m_fifo_timer = new TQTimer (this);
-      connect (m_fifo_timer, SIGNAL (timeout()), SLOT (sendFifoData()));
+      connect (m_fifo_timer, TQ_SIGNAL (timeout()), TQ_SLOT (sendFifoData()));
       m_fifo_timer -> start (100);
     }
   }
