@@ -52,7 +52,7 @@ TQString listEntry (TQComboBox* combo, bool hasDefault = false)
 KPlayerPropertiesDialog::KPlayerPropertiesDialog (void)
   : KDialogBase (TreeList, i18n("File Properties"), Help | Default | Ok | Apply | Cancel, Ok)
 {
-  TQApplication::connect (this, SIGNAL (aboutToShowPage (TQWidget*)), this, SLOT (pageAboutToShow(TQWidget*)));
+  TQApplication::connect (this, TQ_SIGNAL (aboutToShowPage (TQWidget*)), this, TQ_SLOT (pageAboutToShow(TQWidget*)));
 }
 
 KPlayerPropertiesDialog::~KPlayerPropertiesDialog (void)
