@@ -62,10 +62,10 @@ bool KPlayerSource::has (bool groups)
 
 void KPlayerSource::connectNodes (KPlayerContainerNode* node)
 {
-  connect (node, SIGNAL (nodesAdded (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)),
-    SLOT (added (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)));
-  connect (node, SIGNAL (nodesRemoved (KPlayerContainerNode*, const KPlayerNodeList&)),
-    SLOT (removed (KPlayerContainerNode*, const KPlayerNodeList&)));
+  connect (node, TQ_SIGNAL (nodesAdded (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)),
+    TQ_SLOT (added (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)));
+  connect (node, TQ_SIGNAL (nodesRemoved (KPlayerContainerNode*, const KPlayerNodeList&)),
+    TQ_SLOT (removed (KPlayerContainerNode*, const KPlayerNodeList&)));
   KPlayerNodeListIterator iterator (node -> nodes());
   while ( KPlayerNode* node = iterator.current() )
   {
@@ -576,7 +576,7 @@ KPlayerDirectorySource::KPlayerDirectorySource (KPlayerContainerNode* parent)
   if ( m_watch.internalMethod() != KDirWatch::Stat )
   {
     m_watch.startScan();
-    connect (&m_watch, SIGNAL (dirty (const TQString&)), SLOT (dirty (const TQString&)));
+    connect (&m_watch, TQ_SIGNAL (dirty (const TQString&)), TQ_SLOT (dirty (const TQString&)));
   }
 #ifdef DEBUG_KPLAYER_SOURCE
   kdDebugTime() << " Path   " << m_directory.path() << "\n";
@@ -747,11 +747,11 @@ KPlayerOriginSource::~KPlayerOriginSource()
 
 void KPlayerOriginSource::connectOrigin (void)
 {
-  connect (parent() -> origin(), SIGNAL (nodesAdded (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)),
-    SLOT (added (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)));
-  connect (parent() -> origin(), SIGNAL (nodesRemoved (KPlayerContainerNode*, const KPlayerNodeList&)),
-    SLOT (removed (KPlayerContainerNode*, const KPlayerNodeList&)));
-  connect (parent() -> origin(), SIGNAL (detached()), SLOT (detach()));
+  connect (parent() -> origin(), TQ_SIGNAL (nodesAdded (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)),
+    TQ_SLOT (added (KPlayerContainerNode*, const KPlayerNodeList&, KPlayerNode*)));
+  connect (parent() -> origin(), TQ_SIGNAL (nodesRemoved (KPlayerContainerNode*, const KPlayerNodeList&)),
+    TQ_SLOT (removed (KPlayerContainerNode*, const KPlayerNodeList&)));
+  connect (parent() -> origin(), TQ_SIGNAL (detached()), TQ_SLOT (detach()));
 }
 
 void KPlayerOriginSource::enumStart (bool groups)
@@ -863,10 +863,10 @@ KPlayerKeySource::~KPlayerKeySource()
 
 void KPlayerKeySource::connectOrigin (void)
 {
-  connect (parent() -> origin() -> source(), SIGNAL (nodesAdded (const KPlayerNodeList&)),
-    SLOT (added (const KPlayerNodeList&)));
-  connect (parent() -> origin() -> source(), SIGNAL (nodesRemoved (const KPlayerNodeList&)),
-    SLOT (removed (const KPlayerNodeList&)));
+  connect (parent() -> origin() -> source(), TQ_SIGNAL (nodesAdded (const KPlayerNodeList&)),
+    TQ_SLOT (added (const KPlayerNodeList&)));
+  connect (parent() -> origin() -> source(), TQ_SIGNAL (nodesRemoved (const KPlayerNodeList&)),
+    TQ_SLOT (removed (const KPlayerNodeList&)));
 }
 
 void KPlayerKeySource::enumStart (bool groups)
@@ -1054,7 +1054,7 @@ KPlayerSearchSource::~KPlayerSearchSource()
 void KPlayerSearchSource::connectOrigin (void)
 {
   connectNodes (parent() -> origin());
-  connect (parent() -> origin(), SIGNAL (detached()), SLOT (detach()));
+  connect (parent() -> origin(), TQ_SIGNAL (detached()), TQ_SLOT (detach()));
 }
 
 bool KPlayerSearchSource::canAddLeaves (void) const
